@@ -33,9 +33,9 @@
 #' \item{sig.r}{standard errors for the bias-corrected QTE estimates. The values reflect
 #' the impact of the bias correction on the estimation precision.}
 #' }
-#' @export
 #' @importFrom stats quantile
 #' @seealso [rdq.band]
+#' @keywords internal
 #' @examples
 #' n = 500
 #' x = runif(n,min=-4,max=4)
@@ -54,8 +54,8 @@
 #' bp = rdq.bias(y[d==1],x[d==1],dz=0,x0=0,z0=NULL,taus=tlevel,hh,hh,fx=fp$ff[(d==1),],cov=0)
 #' bm = rdq.bias(y[d==0],x[d==0],dz=0,x0=0,z0=NULL,taus=tlevel,hh,hh,fx=fm$ff[(d==0),],cov=0)
 #'
-#' sa = rdq.sim(x=x,d=d,x0=0,z0=NULL,dz=0,cov=0,tt=tlevel,hh,hh,fxp=fp$ff,fxm=fm$ff,n.sim=200)
-#' ba = make.band(n,Dc.p=sa$dcp,Dc.m=sa$dcm,Dr.p=sa$drp,Dr.m=sa$drm,dz=0,cov=0,
+#' sa = QTE.RD:::rdq.sim(x=x,d=d,x0=0,z0=NULL,dz=0,cov=0,tt=tlevel,hh,hh,fxp=fp$ff,fxm=fm$ff,n.sim=200)
+#' ba = QTE.RD:::make.band(n,Dc.p=sa$dcp,Dc.m=sa$dcm,Dr.p=sa$drp,Dr.m=sa$drm,dz=0,cov=0,
 #' taus=tlevel,hh,Qy.p=as.matrix(ab$qp.est[sel,]),Qy.m=as.matrix(ab$qm.est[sel,]),
 #' bias.p=bp$bias,bias.m=bm$bias,alpha=0.1,n.sim=200)
 #'
@@ -69,35 +69,23 @@ make.band <- function(n.sam,Dc.p,Dc.m,Dr.p,Dr.m,dz,cov,taus,hh,Qy.p,Qy.m,bias.p,
   uci <- array(0,c(m,2,dg)); uci.r <- uci
   Qd <- array(0,c(m,dg)); Qd.adj <- Qd
   sig <- array(0,c(m,dg)); sig.r <- sig
+
   for(i in 1:dg){
     Gs <- Dc.p[i,,] - Dc.m[i,,]
     Gr <- Dr.p[i,,] - Dr.m[i,,]
-    Qy <- Qy.p[,i] - Qy.m[,i]
-    Qy.adj <- Qy - (bias.p[,i] - bias.m[,i])
-
-    # uniform band
-    if(m==1){shat <- sqrt(mean(Gs*Gs))}
-    if(m >1){shat <- sqrt(apply((Gs*Gs),1,mean))}
-    ra <- Gs/matrix(rep(shat,n.sim),ncol=n.sim)
-    rs <- apply(abs(ra),2,max)
-    cp <- quantile(rs,probs=(1-alpha))
-    sigma <- shat/sqrt(n.sam*hh)
-    uci[,,i] <- cbind((Qy - cp*sigma),(Qy + cp*sigma))
-
-    # robust uniform band
-    if(m==1){shat2 <- sqrt(mean(Gr*Gr))}
-    if(m >1){shat2 <- sqrt(apply((Gr*Gr),1,mean))}
-    ra2 <- Gr/matrix(rep(shat2,n.sim),ncol=n.sim)
-    rs2 <- apply(abs(ra2),2,max)
-    cp2 <- quantile(rs2,probs=(1-alpha))
-    sigma2 <- shat2/sqrt(n.sam*hh)
-    uci.r[,,i] <- cbind((Qy.adj - cp2*sigma2),(Qy.adj + cp2*sigma2))
-
-    # point estimates
+    Qy <- Qy.p[, i] - Qy.m[, i]
+    Qy.adj <- Qy - (bias.p[, i] - bias.m[, i])
+    # Uniform band
+    res_s <- compute.bands(Gs, Qy, n.sim, n.sam, hh, alpha)
+    uci[,,i] <- res_s$band
+    sig[,i] <- res_s$sigma
+    # Robust uniform band
+    res_r <- compute.bands(Gr, Qy.adj, n.sim, n.sam, hh, alpha)
+    uci.r[,,i] <- res_r$band
+    sig.r[,i] <- res_r$sigma
+    # Point estimates
     Qd[,i] <- Qy
     Qd.adj[,i] <- Qy.adj
-    # sigma
-    sig[,i] <- sigma; sig.r[,i] <- sigma2
   }
   return(list(qte = Qd, qte.r = Qd.adj, uband = uci, uband.r = uci.r, s = sig, s.r = sig.r))
 }
