@@ -46,8 +46,9 @@
 #' \item{sm.r}{standard errors of the conditional quantile estimates with robust
 #' bias correction at \eqn{x_{0}^{-}}.}
 #' }
-#' @export
 #' @importFrom quantreg bandwidth.rq
+#'
+#' @keywords internal
 #' @seealso [make.band]
 #' @examples
 #' n = 500
@@ -67,8 +68,8 @@
 #' bp = rdq.bias(y[d==1],x[d==1],dz=0,x0=0,z0=NULL,taus=tlevel,hh,hh,fx=fp$ff[(d==1),],cov=0)
 #' bm = rdq.bias(y[d==0],x[d==0],dz=0,x0=0,z0=NULL,taus=tlevel,hh,hh,fx=fm$ff[(d==0),],cov=0)
 #'
-#' sa = rdq.sim(x=x,d=d,x0=0,z0=NULL,dz=0,cov=0,tt=tlevel,hh,hh,fxp=fp$ff,fxm=fm$ff,n.sim=200)
-#' ba.cq = make.band.cq(n,Dc.p=sa$dcp,Dc.m=sa$dcm,Dr.p=sa$drp,Dr.m=sa$drm,dz=0,cov=0,
+#' sa = QTE.RD:::rdq.sim(x=x,d=d,x0=0,z0=NULL,dz=0,cov=0,tt=tlevel,hh,hh,fxp=fp$ff,fxm=fm$ff,n.sim=200)
+#' ba.cq = QTE.RD:::make.band.cq(n,Dc.p=sa$dcp,Dc.m=sa$dcm,Dr.p=sa$drp,Dr.m=sa$drm,dz=0,cov=0,
 #' taus=tlevel,hh,Qy.p=as.matrix(ab$qp.est[sel,]),Qy.m=as.matrix(ab$qm.est[sel,]),
 #' bias.p=bp$bias,bias.m=bm$bias,alpha=0.1,n.sim=200)
 #'
@@ -84,40 +85,34 @@ make.band.cq <- function(n.sam,Dc.p,Dc.m,Dr.p,Dr.m,dz,cov,taus,hh,Qy.p,Qy.m,bias
   Qp <- array(0,c(m,dg)); Qp.adj <- Qp; Qm <- Qp; Qm.adj <- Qp
   sigp <- array(0,c(m,dg)); sigp.r <- sigp
   sigm <- array(0,c(m,dg)); sigm.r <- sigm
-  for(k in 1:2){
-    for(i in 1:dg){
-      if(k==1){Gs <- Dc.p[i,,]; Gr <- Dr.p[i,,]}
-      if(k==2){Gs <- Dc.m[i,,]; Gr <- Dr.m[i,,]}
-      if(k==1){Qy <- Qy.p[,i]; Qy.adj <- Qy.p[,i] - bias.p[,i]}
-      if(k==2){Qy <- Qy.m[,i]; Qy.adj <- Qy.m[,i] - bias.m[,i]}
-
-      # uniform band
-      if(m==1){shat <- sqrt(mean(Gs*Gs))}
-      if(m >1){shat <- sqrt(apply((Gs*Gs),1,mean))}
-      ra <- Gs/matrix(rep(shat,n.sim),ncol=n.sim)
-      rs <- apply(abs(ra),2,max)
-      cp <- quantile(rs,probs=(1-alpha))
-      sigma <- shat/sqrt(n.sam*hh)
-      if(k==1){uci.p[,,i] <- cbind((Qy - cp*sigma),(Qy + cp*sigma))}
-      if(k==2){uci.m[,,i] <- cbind((Qy - cp*sigma),(Qy + cp*sigma))}
-
-      # robust uniform band
-      if(m==1){shat2 <- sqrt(mean(Gr*Gr))}
-      if(m >1){shat2 <- sqrt(apply((Gr*Gr),1,mean))}
-      ra2 <- Gr/matrix(rep(shat2,n.sim),ncol=n.sim)
-      rs2 <- apply(abs(ra2),2,max)
-      cp2 <- quantile(rs2,probs=(1-alpha))
-      sigma2 <- shat2/sqrt(n.sam*hh)
-      if(k==1){ucr.p[,,i] <- cbind((Qy.adj - cp2*sigma2),(Qy.adj + cp2*sigma2))}
-      if(k==2){ucr.m[,,i] <- cbind((Qy.adj - cp2*sigma2),(Qy.adj + cp2*sigma2))}
-
-      # point estimates
-      if(k==1){Qp[,i] <- Qy; Qp.adj[,i] <- Qy.adj}
-      if(k==2){Qm[,i] <- Qy; Qm.adj[,i] <- Qy.adj}
-
-      # sigma
-      if(k==1){sigp[,i] <- sigma; sigp.r[,i] <- sigma2}
-      if(k==2){sigm[,i] <- sigma; sigm.r[,i] <- sigma2}
+  for (k in 1:2) {
+    for (i in 1:dg){
+      if(k==1){
+        Gs <- Dc.p[i,,]; Gr <- Dr.p[i,,]
+        Qy <- Qy.p[, i]; Qy.adj <- Qy - bias.p[, i]
+      }
+      if(k==2){
+        Gs <- Dc.m[i,,]; Gr <- Dr.m[i,,]
+        Qy <- Qy.m[, i]; Qy.adj <- Qy - bias.m[, i]
+      }
+      res_s <- compute.bands(Gs, Qy, n.sim, n.sam, hh, alpha)
+      res_r <- compute.bands(Gr, Qy.adj, n.sim, n.sam, hh, alpha)
+      if(k==1){
+        uci.p[,,i] <- res_s$band
+        ucr.p[,,i] <- res_r$band
+        Qp[,i] <- Qy
+        Qp.adj[,i] <- Qy.adj
+        sigp[,i] <- res_s$sigma
+        sigp.r[,i] <- res_r$sigma
+      }
+      if(k==2){
+        uci.m[,,i] <- res_s$band
+        ucr.m[,,i] <- res_r$band
+        Qm[,i] <- Qy
+        Qm.adj[,i] <- Qy.adj
+        sigm[,i] <- res_s$sigma
+        sigm.r[,i] <- res_r$sigma
+      }
     }
   }
   return(list(qp = Qp, qm = Qm, qp.r = Qp.adj, qm.r = Qm.adj, ubandp = uci.p, ubandp.r = ucr.p, ubandm = uci.m, ubandm.r = ucr.m, sp = sigp, sp.r = sigp.r, sm = sigm, sm.r = sigm.r))
